@@ -28,13 +28,19 @@ class FontDialog : public QDialog, public Ui::FontDialog
 {
     Q_OBJECT
 public:
-    FontDialog(const QFont &f);
+    FontDialog(const QFont &f, QWidget *parent = nullptr);
     QFont getFont();
+    void drawBorder();
+
+protected:
+    void paintEvent(QPaintEvent *event);
 
 private slots:
     void setFontSample(const QFont &f);
     void setFontSize();
 
+private:
+    bool mDrawBorder;
 };
 
 #endif
