@@ -116,6 +116,13 @@ void parse_args(int argc, char* argv[], QString& workdir, QStringList & shell_co
         }
     }
     while(next_option != -1);
+
+    // FIXME: The app might not exit in the dropdown mode after the shell command is terminated
+    // and the window is closed. For now, the dropdown mode is disabled with command execution.
+    if (!shell_command.isEmpty())
+    {
+        dropMode = false;
+    }
 }
 
 int main(int argc, char *argv[])
