@@ -83,6 +83,7 @@ void Properties::loadSettings()
     colorScheme = m_settings->value(QLatin1String("colorScheme"), QLatin1String("Linux")).toString();
 
     highlightCurrentTerminal = m_settings->value(QLatin1String("highlightCurrentTerminal"), true).toBool();
+    focusOnMoueOver = m_settings->value(QLatin1String("focusOnMoueOver"), false).toBool();
     showTerminalSizeHint = m_settings->value(QLatin1String("showTerminalSizeHint"), true).toBool();
 
     font = QFont(qvariant_cast<QString>(m_settings->value(QLatin1String("fontFamily"), defaultFont().family())),
@@ -114,7 +115,6 @@ void Properties::loadSettings()
 
     terminalMargin = m_settings->value(QLatin1String("TerminalMargin"), 0).toInt();
 
-    appTransparency = m_settings->value(QLatin1String("MainWindow/ApplicationTransparency"), 0).toInt();
     termTransparency = m_settings->value(QLatin1String("TerminalTransparency"), 0).toInt();
     backgroundImage = m_settings->value(QLatin1String("TerminalBackgroundImage"), QString()).toString();
     backgroundMode = qBound(0, m_settings->value(QLatin1String("TerminalBackgroundMode"), 0).toInt(), 4);
@@ -122,9 +122,10 @@ void Properties::loadSettings()
     /* default to Right. see qtermwidget.h */
     scrollBarPos = m_settings->value(QLatin1String("ScrollbarPosition"), 2).toInt();
     /* default to North. I'd prefer South but North is standard (they say) */
-    tabsPos = m_settings->value(QLatin1String("TabsPosition"), 0).toInt();
+    tabsPos = qBound(0, m_settings->value(QLatin1String("TabsPosition"), 0).toInt(), 3);
     /* default to BlockCursor */
     keyboardCursorShape = m_settings->value(QLatin1String("KeyboardCursorShape"), 0).toInt();
+    keyboardCursorBlink = m_settings->value(QLatin1String("KeyboardCursorBlink"), false).toBool();
     hideTabBarWithOneTab = m_settings->value(QLatin1String("HideTabBarWithOneTab"), false).toBool();
     // For "Motion after paste", 2 (scrolling to bottom) makes more sense
     m_motionAfterPaste = m_settings->value(QLatin1String("MotionAfterPaste"), 2).toInt();
@@ -164,8 +165,8 @@ void Properties::loadSettings()
     dropShortCut = QKeySequence(m_settings->value(QLatin1String("ShortCut"), QLatin1String("F12")).toString());
     dropKeepOpen = m_settings->value(QLatin1String("KeepOpen"), false).toBool();
     dropShowOnStart = m_settings->value(QLatin1String("ShowOnStart"), true).toBool();
-    dropWidth = m_settings->value(QLatin1String("Width"), 70).toInt();
-    dropHeight = m_settings->value(QLatin1String("Height"), 45).toInt();
+    dropWidth = qBound(25, m_settings->value(QLatin1String("Width"), 70).toInt(), 100);
+    dropHeight = qBound(25, m_settings->value(QLatin1String("Height"), 45).toInt(), 100);
     m_settings->endGroup();
 
     changeWindowTitle = m_settings->value(QLatin1String("ChangeWindowTitle"), true).toBool();
@@ -181,6 +182,16 @@ void Properties::loadSettings()
 
     swapMouseButtons2and3 = m_settings->value(QLatin1String("SwapMouseButtons2and3"), false).toBool();
 
+    mouseAutoHideDelay = m_settings->value(QLatin1String("MouseAutoHideDelay"), -1).toInt();
+    if (mouseAutoHideDelay > 0)
+    {
+        mouseAutoHideDelay *= 1000;
+    }
+    else
+    {
+        mouseAutoHideDelay = -1; // disable (no zero delay)
+    }
+
     prefDialogSize = m_settings->value(QLatin1String("PrefDialogSize")).toSize();
 }
 
@@ -189,6 +200,7 @@ void Properties::saveSettings()
     m_settings->setValue(QLatin1String("guiStyle"), guiStyle);
     m_settings->setValue(QLatin1String("colorScheme"), colorScheme);
     m_settings->setValue(QLatin1String("highlightCurrentTerminal"), highlightCurrentTerminal);
+    m_settings->setValue(QLatin1String("focusOnMoueOver"), focusOnMoueOver);
     m_settings->setValue(QLatin1String("showTerminalSizeHint"), showTerminalSizeHint);
     m_settings->setValue(QLatin1String("fontFamily"), font.family());
     m_settings->setValue(QLatin1String("fontSize"), font.pointSize());
@@ -235,7 +247,6 @@ void Properties::saveSettings()
     }
     m_settings->endArray();
 
-    m_settings->setValue(QLatin1String("MainWindow/ApplicationTransparency"), appTransparency);
     m_settings->setValue(QLatin1String("TerminalMargin"), terminalMargin);
     m_settings->setValue(QLatin1String("TerminalTransparency"), termTransparency);
     m_settings->setValue(QLatin1String("TerminalBackgroundImage"), backgroundImage);
@@ -243,6 +254,7 @@ void Properties::saveSettings()
     m_settings->setValue(QLatin1String("ScrollbarPosition"), scrollBarPos);
     m_settings->setValue(QLatin1String("TabsPosition"), tabsPos);
     m_settings->setValue(QLatin1String("KeyboardCursorShape"), keyboardCursorShape);
+    m_settings->setValue(QLatin1String("KeyboardCursorBlink"), keyboardCursorBlink);
     m_settings->setValue(QLatin1String("HideTabBarWithOneTab"), hideTabBarWithOneTab);
     m_settings->setValue(QLatin1String("MotionAfterPaste"), m_motionAfterPaste);
     m_settings->setValue(QLatin1String("DisableBracketedPasteMode"), m_disableBracketedPasteMode);
@@ -293,6 +305,17 @@ void Properties::saveSettings()
     m_settings->setValue(QLatin1String("LastWindowMaximized"), windowMaximized);
     m_settings->setValue(QLatin1String("SwapMouseButtons2and3"), swapMouseButtons2and3);
 
+    int autoDelay = mouseAutoHideDelay;
+    if (autoDelay > 0)
+    {
+        autoDelay /= 1000;
+    }
+    else
+    {
+        autoDelay = 0; // means disabling when saved
+    }
+    m_settings->setValue(QLatin1String("MouseAutoHideDelay"), autoDelay);
+
     m_settings->setValue(QLatin1String("PrefDialogSize"), prefDialogSize);
 
     // the config file may be created now
@@ -364,21 +387,6 @@ void Properties::migrate_settings()
         }
         settings.remove(QLatin1String("AlwaysShowTabs"));
 
-        // ===== appOpacity -> ApplicationTransparency =====
-        //
-        // Note: In 0.6.0 the opacity values had been erroneously
-        // restricted to [0,99] instead of [1,100]. We fix this here by
-        // setting the opacity to 100 if it was 99 and to 1 if it was 0.
-        //
-        if(!settings.contains(QLatin1String("MainWindow/ApplicationTransparency")))
-        {
-            int appOpacityValue = settings.value(QLatin1String("MainWindow/appOpacity"), 100).toInt();
-            appOpacityValue = appOpacityValue == 99 ? 100 : appOpacityValue;
-            appOpacityValue = appOpacityValue == 0 ? 1 : appOpacityValue;
-            settings.setValue(QLatin1String("MainWindow/ApplicationTransparency"), 100 - appOpacityValue);
-        }
-        settings.remove(QLatin1String("MainWindow/appOpacity"));
-
         // ===== termOpacity -> TerminalTransparency =====
         if(!settings.contains(QLatin1String("TerminalTransparency")))
         {
@@ -411,6 +419,14 @@ void Properties::removeAccelerator(QString& str)
     str.remove(QLatin1Char('&'));
 }
 
+QString Properties::getShortcut(const QString &name, const QString &defaultShortcut) const
+{
+    m_settings->beginGroup(QStringLiteral("Shortcuts"));
+    QString sequence = m_settings->value(name, defaultShortcut).toString();
+    m_settings->endGroup();
+    return sequence;
+}
+
 QString Properties::configDir() const
 {
     return QFileInfo(m_settings->fileName()).absoluteDir().canonicalPath();
