@@ -57,6 +57,8 @@ TermWidgetImpl::TermWidgetImpl(TerminalConfig &cfg, QWidget * parent)
     setFlowControlEnabled(FLOW_CONTROL_ENABLED);
     setFlowControlWarningEnabled(FLOW_CONTROL_WARNING_ENABLED);
 
+    m_hasCommand = cfg.hasCommand();
+
     propertiesChanged();
 
     setWorkingDirectory(cfg.getWorkingDirectory());
@@ -112,6 +114,7 @@ void TermWidgetImpl::propertiesChanged()
     disableBracketedPasteMode(Properties::Instance()->m_disableBracketedPasteMode);
     setConfirmMultilinePaste(Properties::Instance()->confirmMultilinePaste);
     setWordCharacters(Properties::Instance()->wordCharacters);
+    autoHideMouseAfter(Properties::Instance()->mouseAutoHideDelay);
     setTrimPastedTrailingNewlines(Properties::Instance()->trimPastedTrailingNewlines);
     setTerminalSizeHint(Properties::Instance()->showTerminalSizeHint);
 
@@ -160,6 +163,8 @@ void TermWidgetImpl::propertiesChanged()
         break;
     }
 
+    setBlinkingCursor(Properties::Instance()->keyboardCursorBlink);
+
     update();
 }
 
@@ -258,19 +263,26 @@ bool TermWidget::eventFilter(QObject * /*obj*/, QEvent * ev)
     if (ev->type() == QEvent::MouseButtonPress)
     {
         QMouseEvent *mev = static_cast<QMouseEvent*>(ev);
-        if ( mev->button() == Qt::MiddleButton )
+        if (mev->button() == Qt::MiddleButton)
         {
             if(Properties::Instance()->swapMouseButtons2and3)
             {
-                    impl()->customContextMenuCall(mev->pos());
+                impl()->customContextMenuCall(mev->pos());
             }
             else
             {
-                    impl()->pasteSelection();
+                impl()->pasteSelection();
             }
             return true;
         }
     }
+    else if ((ev->type() == QEvent::MouseMove
+              || ev->type() == QEvent::Enter
+              || ev->type() == QEvent::HoverEnter)
+             && Properties::Instance()->focusOnMoueOver)
+    {
+        impl()->setFocus();
+    }
     return false;
 }
 
